Estimate the malariasimulation input distribution from usage assumes a specified net loss function and randomly correlated net distribution.
usage_to_model_distribution.RdEstimate the malariasimulation input distribution from usage assumes a specified net loss function and randomly correlated net distribution.
Arguments
- usage
Target usage
- usage_timesteps
Target usage time points
- distribution_timesteps
A vector of distribution time steps
- distribution_lower
Lower bound on distributions (default = 0)
- distribution_upper
Upper bound on distribution (default = 1)
- net_loss_function
Function to calculate net retention over time. Should take time as first argument and return proportion retained. Defaults to net_loss_exp for backward compatibility.
- ...
Additional arguments passed to net_loss_function